@@ -98,3 +98,20 @@ class Test_Alpha_Shapes(TestCase):
         ashape, radius, centers = alpha_shape_auto(self.vertices, return_circles=True)
         np.testing.assert_allclose(radius, self.circle_radii)
         np.testing.assert_allclose(centers, self.circle_verts)
+    
+    def test_holes(self):
+        np.random.seed(seed=100)
+        points = np.random.rand(1000, 2)*100
+        inv_alpha = 3.5
+        geoms = alpha_shape(points, 1/inv_alpha)
+        assert len(geoms) == 1
+        holes = geopandas.GeoSeries(geoms.interiors.explode()).reset_index(drop=True)
+        assert len(holes) == 30
+        # No holes are within the shape (shape has holes already)
+        result = geoms.sindex.query_bulk(holes.centroid, predicate='within')
+        assert result.shape == (2,0)
+        # All holes are within the exterior
+        shell = geopandas.GeoSeries(geoms.exterior.apply(geometry.Polygon))
+        within, outside = shell.sindex.query_bulk(holes.centroid, predicate='within')
+        assert (outside == 0).all()
+        np.testing.assert_array_equal(within, np.arange(30))
\ No newline at end of file
