@@ -8,9 +8,7 @@ Base class for managing example datasets.
 import io
 import os
 import webbrowser
-from os import environ, makedirs
-from os.path import exists, expanduser, join
-from appdirs import user_data_dir
+from platformdirs import user_data_dir
 import zipfile
 import requests
 import pandas
@@ -35,9 +33,9 @@ def get_data_home():
 
     appname = "pysal"
     appauthor = "pysal"
-    data_home =  user_data_dir(appname, appauthor) 
-    if not exists(data_home):
-        makedirs(data_home, exist_ok=True)
+    data_home = user_data_dir(appname, appauthor)
+    if not os.path.exists(data_home):
+        os.makedirs(data_home, exist_ok=True)
     return data_home
 
 
@@ -122,7 +120,9 @@ class Example:
 
     """
 
-    def __init__(self, name, description, n, k, download_url, explain_url):
+    def __init__(self, name, description, n, k, download_url,
+                 explain_url):
+        """Initialze Example."""
         self.name = name
         self.description = description
         self.n = n
@@ -134,12 +134,10 @@ class Example:
 
     def get_local_path(self, path=get_data_home()) -> str:
         """Get the local path for example."""
-
-        return join(path, self.root)
+        return os.path.join(path, self.root)
 
     def get_path(self, file_name, verbose=True) -> Union[str, None]:
         """Get the path for local file."""
-
         file_list = self.get_file_list()
         for file_path in file_list:
             base_name = os.path.basename(file_path)
@@ -151,7 +149,6 @@ class Example:
 
     def downloaded(self) -> bool:
         """Check if the example has already been installed."""
-
         path = self.get_local_path()
         if os.path.isdir(path):
             self.installed = True
@@ -180,7 +177,7 @@ class Example:
         if not self.downloaded():
             request = requests.get(self.download_url)
             archive = zipfile.ZipFile(io.BytesIO(request.content))
-            target = join(path, self.root)
+            target = os.path.join(path, self.root)
             print("Downloading {} to {}".format(self.name, target))
             archive.extractall(path=target)
             self.zipfile = archive
@@ -213,8 +210,8 @@ class Example:
 class Examples:
     """Manager for pysal example datasets."""
 
-    def __init__(self):
-        self.datasets = {}
+    def __init__(self, datasets={}):
+        self.datasets = datasets
 
     def add_examples(self, examples):
         """Add examples to the set of datasets available."""
@@ -273,5 +270,23 @@ class Examples:
         ds = self.datasets
         return [name for name in ds if ds[name].installed]
 
+    def get_remote_url(self, name):
+        if name in self.datasets: 
+            try:
+                return self.datasets[name].download_url
+            except:
+                print(f'{name} is a built-in dataset, no url.')
+        else:
+            print(f'{name} is not an available dataset.')
+                
+
+    def summary(self):
+        """Report on datasets."""
+        available = self.available()
+        n = available.shape[0]
+        n_installed = available.Installed.sum()
+        n_remote = n - n_installed
+        print(f'{n} datasets available, {n_installed} installed, {n_remote} remote.')
+
 
 example_manager = Examples()
