@@ -9,6 +9,7 @@ from ...io import geotable as pdio
 from ... import examples as pysal_examples
 import unittest as ut
 import numpy as np
+import pytest
 
 PANDAS_EXTINCT = pandas is None
 try:
@@ -18,6 +19,12 @@ try:
 except ImportError:
     GEOPANDAS_EXTINCT = True
 
+try:
+    import shapely
+    HAS_SHAPELY = True
+except ImportError:
+    HAS_SHAPELY = False
+
 
 class Contiguity_Mixin(object):
     polygon_path = pysal_examples.get_path("columbus.shp")
@@ -90,6 +97,7 @@ class Contiguity_Mixin(object):
         # test named, sparse from point array
         pass
 
+
     @ut.skipIf(PANDAS_EXTINCT, "Missing pandas")
     def test_from_dataframe(self):
         # basic
@@ -102,7 +110,12 @@ class Contiguity_Mixin(object):
         w = self.cls.from_dataframe(df, geom_col="the_geom")
         self.assertEqual(w[self.known_wi], self.known_w)
 
+
+    @ut.skipIf(GEOPANDAS_EXTINCT, "Missing geopandas")
+    def test_from_geodataframe(self):
+        df = pdio.read_files(self.polygon_path)
         # named active geometry
+        df.rename(columns={"geometry": "the_geom"}, inplace=True)
         df = df.set_geometry("the_geom")
         w = self.cls.from_dataframe(df)
         self.assertEqual(w[self.known_wi], self.known_w)
@@ -148,7 +161,7 @@ class Test_Queen(ut.TestCase, Contiguity_Mixin):
             (1, -90.0, 60.0): 1,
             (1, -30.0, -180.0): 1,
             (1, -30.0, 60.0): 1,
-            (1, 30.0, -180.0): 1, 
+            (1, 30.0, -180.0): 1,
             (1, 30.0, -60.0): 1,
             (1, 30.0, 60.0): 1
             }
@@ -192,6 +205,7 @@ class Test_Rook(ut.TestCase, Contiguity_Mixin):
 
 
 class Test_Voronoi(ut.TestCase):
+    @pytest.mark.skipif(not HAS_SHAPELY, reason="shapely needed")
     def test_voronoiW(self):
         np.random.seed(12345)
         points = np.random.random((5, 2)) * 10 + 10
